@@ -1,6 +1,6 @@
 target.arrival.sf <-
 function(xdata, ydata, date, t, rts = "crs", g = NULL,
-                              wd = NULL, sg = "ssm", ftype = "d", cv = "convex"){
+                              wd = NULL, sg = "ssm", ftype = "d", cv = "convex", anc = FALSE){
   
   # Initial checks
   if(t <= min(date))                                   stop('t is earlier than dataset.')
@@ -22,12 +22,14 @@ function(xdata, ydata, date, t, rts = "crs", g = NULL,
   rts   <- ifelse(cv == "fdh", "vrs", rts)
   r     <- tail(which(sort(date) <= t), 1)
   id_f  <- which(date > t)
+  org   <- unique(sort(date)[1:r])[-1]
   
   # Data frames
   eff_t       <- array(NA, c(n, 1))
   eff_t_gm    <- array(NA, c(n, 1)) # Geometric mean for equi-ratio
   lambda      <- array(NA, c(n, n))
   ed          <- array(NA, c(n, 1))
+  roc_anc     <- array(NA, c(n, 1))
   roc_ind     <- array(NA, c(n, 1))
   arrival_avg <- array(NA, c(n, 1))
   arrival_seg <- array(NA, c(n, 1))
@@ -48,12 +50,27 @@ function(xdata, ydata, date, t, rts = "crs", g = NULL,
   ed[id_f,] <- if(ftype == "s") rep(t, n - r) else lambda[id_f, -id_f] %*% date[-id_f,] / rowSums(lambda[id_f, -id_f])
   
   # RoC
-  sf_roc         <- roc.sf(xdata, ydata, date, t, rts, g, wd, sg, ftype, cv)
-  roc_local      <- sf_roc$roc_local
-  roc_avg        <- sf_roc$roc_avg
+  if(anc == T){
+    for(i in org){
+      origin  <- i
+      roc_t   <- roc.sf(xdata, ydata, date, t, rts, g, wd, sg, ftype, cv)
+      roc_anc <- cbind(roc_anc, roc_t$roc_local)
+    }
+    roc_anc   <- roc_anc[, -1, drop = F] # For coding convenience, could be improved
+    id_lroc   <- which(!is.na(roc_anc[, length(org)]))
+    roc_prmr  <- matrix(apply(roc_anc[id_lroc,, drop = F], 1, 
+                              function(x) ifelse(all(is.na(x)), NA, x[which(!is.na(x))[1]])), ncol = 1)
+    roc_local <- array(NA, c(n, 1))
+    roc_prmr  -> roc_local[id_lroc,]
+    roc_avg   <- mean(roc_anc[, dim(roc_anc)[2]], na.rm = T)
+  }else{
+    roc_t     <- roc.sf(xdata, ydata, date, t, rts, g, wd, sg, ftype, cv)
+    roc_local <- roc_t$roc_local
+    roc_avg   <- roc_t$roc_avg
+  }
   id_lroc        <- which(!is.na(roc_local))
   roc_ind[id_f,] <- lambda[id_f, id_lroc, drop = F] %*% roc_local[id_lroc,] / rowSums(lambda[id_f, id_lroc, drop = F])
-
+  
   # Arrival target
   eff_t_gm[id_f,]      <- ((1 - eff_t[id_f,]) / (1 + eff_t[id_f,]))^0.5 # Geometric mean for equi-ratio
   roc_avg              -> roc_ind[!is.na(roc_ind) & roc_ind == 0 | is.nan(roc_ind),]  # replace 0 or NaN with roc_avg
@@ -62,7 +79,7 @@ function(xdata, ydata, date, t, rts = "crs", g = NULL,
   arrival_seg[id_eff,] <- ed[id_eff,] + log(eff_t_gm[id_eff,], exp(1)) / log(roc_ind[id_eff,], exp(1))
   
   results <- list(eff_t = eff_t, lambda_t = lambda, eft_date = ed, 
-                  roc_avg = roc_avg, roc_local = roc_local, roc_ind = roc_ind, 
+                  roc_avg = roc_avg, roc_anc = roc_anc, roc_local = roc_local, roc_ind = roc_ind, 
                   arrival_avg = arrival_avg, arrival_seg = arrival_seg)
   return(results)    
 }
